TransmitAuth class final

Clear public-facing SDK entry point that mirrors TransmitSDK.

Inheritance

Constructors

TransmitAuth.fromConfig({required TransmitAuthConfig config, Client? client})
Creates a TransmitAuth instance from a prebuilt configuration object.
TransmitAuth.withApiKey({required String apiKey, required String serviceId, TransmitRegion region = TransmitRegion.global, Client? client})
Creates a TransmitAuth instance using API key authentication.

Properties

Service for authenticating with magic links
latefinalinherited
authenticateNativeMobileBiometrics AortemTransmitAuthenticateNativeMobileBiometrics
Service for native mobile biometric authentication
latefinalinherited
authenticateOTP AortemTransmitAuthenticateOTP
Service for authenticating with OTP codes
latefinalinherited
authenticatePassword AortemTransmitAuthenticatePassword
Service for password authentication
latefinalinherited
authenticateSession AortemTransmitAuthenticateSession
Service for authenticating sessions
latefinalinherited
authenticateTOTP AortemTransmitAuthenticateTOTP
Service for authenticating with TOTP
latefinalinherited
authenticateTransactionTOTP AortemTransmitAuthenticateTransactionTOTP
Service for authenticating TOTP transactions
latefinalinherited
authenticateWebAuthnCredential AortemTransmitAuthenticateWebAuthnCredential
Service for authenticating with WebAuthn credentials
latefinalinherited
authenticationStartWebAuthn AortemTransmitAuthenticationStartWebAuthn
Service for starting WebAuthn authentication
latefinalinherited
authorization AortemTransmitAuthorization
Authorization services for flexible access control
latefinalinherited
getUserSessions AortemTransmitGetUserSessions
Service for retrieving user sessions
latefinalinherited
hashCode int
The hash code for this object.
no setterinherited
hostedWebAuthnRegistrationHint AortemTransmitHostedWebAuthnRegistrationHint
Service for Hosting WebAuthn Registration
latefinalinherited
journeyToken AortemTransmitJourneyToken
Journey token services
latefinalinherited
logoutBackendSession AortemTransmitLogoutBackendSession
Service for logging out backend sessions
latefinalinherited
mobileBiometricsRegistration AortemTransmitMobileBiometricsRegistration
Service for mobile biometric registration
latefinalinherited
refreshBackendAuthToken AortemTransmitRefreshUserSession
Service for refreshing backend auth tokens
latefinalinherited
registerTOTP AortemTransmitRegisterTOTP
Service for registering TOTP devices
latefinalinherited
revokeTOTP AortemTransmitRevokeTOTP
Service for revoking TOTP devices
latefinalinherited
revokeTOTPManagement AortemTransmitRevokeTOTPManagement
Service for managing TOTP devices
latefinalinherited
revokeUserSessions UserSessionManager
Service for managing user sessions
latefinalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchQuery AortemTransmitSearchQueryService
Search query services
latefinalinherited
Service for sending magic links
latefinalinherited
sendOTP AortemTransmitSendOTP
Service for sending OTP codes
latefinalinherited
startTransactionTOTP AortemTransmitStartTransactionTOTP
Service for starting TOTP transactions
latefinalinherited
tokenManager AortemTransmitTokenManager
Token management services
latefinalinherited
tokenRefresh AortemTransmitTokenRefresh
Token refresh services
latefinalinherited
tokenReset AortemTransmitTokenReset
Token reset services
latefinalinherited
webAuthnCrossDeviceAbort AortemTransmitWebAuthnCrossDeviceAbort
Service for aborting WebAuthn cross-device operations
latefinalinherited
webAuthnCrossDeviceAttachDevice AortemTransmitWebAuthnCrossDeviceAttachDevice
Service for attaching WebAuthn cross-device
latefinalinherited
webAuthnCrossDeviceAuthenticateStart AortemTransmitWebAuthnCrossDeviceAuthenticateStart
Service for WebAuthn cross-device authentication start
latefinalinherited
webAuthnCrossDeviceAuthenticationInit AortemTransmitWebAuthnCrossDeviceAuthenticationInit
Service for WebAuthn cross-device authentication initialization
latefinalinherited
webAuthnCrossDeviceRegistrationInit AortemTransmitWebAuthnCrossDeviceRegistrationInit
Handles initiating cross-device WebAuthn registration.
latefinalinherited
webAuthnCrossDeviceStatus AortemTransmitWebAuthnCrossDeviceStatus
Service for checking WebAuthn cross-device status
latefinalinherited
webAuthnRegistration AortemTransmitWebAuthnRegistration
Handles completion of WebAuthn credential registration for users who are already logged in.
latefinalinherited
webAuthnRegistrationExternal AortemTransmitWebAuthnRegistrationExternal
Handles completing external WebAuthn registration.
latefinalinherited
webAuthnRegistrationStart AortemTransmitWebAuthnRegistrationStart
Handles starting a new WebAuthn registration flow.
latefinalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateConfig(TransmitAuthConfig newConfig) → void
Updates the SDK configuration with new settings.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited